package com.mt.wms.core.dal.entity;

import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.baomidou.mybatisplus.annotation.Version;
import com.baomidou.mybatisplus.annotation.TableId;
import java.time.LocalDateTime;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableField;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 当前任务
 * </p>
 *
 * @author mt
 * @since 2021-11-09
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("t_curr_task")
public class CurrTask extends Model<CurrTask> {

    private static final long serialVersionUID = 1L;

      @TableId(value = "id", type = IdType.AUTO)
    private Long id;

    /**
     * 删除标志，是否有效:1 可用 0不可用，2停止
     */
    @TableField("valid")
    @TableLogic
    private Integer valid;

    /**
     * 添加时间，每次修改记录要更新记录新增时间
     */
    @TableField("create_time")
    private LocalDateTime createTime;

    /**
     * 创建人id
     */
    @TableField("creator_id")
    private Integer creatorId;

    /**
     * 更新人id
     */
    @TableField("updater_id")
    private Integer updaterId;

    /**
     * 修改时间，更具修改时间来判断下次执行顺序，第一次修改时间和新增时间相同
     */
    @TableField("update_time")
    private LocalDateTime updateTime;

    /**
     * 版本号 默认为 1
     */
    @TableField("version")
    @Version
    private String version;

    /**
     * 状态：	0等待执行，1执行中，2执行完成，3追加后完成（追加后就按完成来算）
     */
    @TableField("status")
    private Integer status;

    /**
     * 内部编码，系统自动生成
     */
    @TableField("inter_code")
    private String interCode;

    /**
     * 任务编码, 查看任务编码规则
     */
    @TableField("task_code")
    private String taskCode;

    /**
     * 托盘编码
     */
    @TableField("pallet_code")
    private String palletCode;

    /**
     * 缓存前开始时间，车辆开始执行
     */
    @TableField("a_begin_time")
    private LocalDateTime aBeginTime;

    /**
     * 完成当前任务时间（可能是到缓存区，有可能直接到窑炉），车辆放完货物到缓存区收到的时间
     */
    @TableField("a_end_time")
    private LocalDateTime aEndTime;

    /**
     * 开始位置
     */
    @TableField("start_position")
    private String startPosition;

    /**
     * 目标位置指的是窑炉的位置
     */
    @TableField("target_position")
    private String targetPosition;

    /**
     * 目标窑炉id
     */
    @TableField("kiln_id")
    private Long kilnId;

    /**
     * 车辆id，关联车辆表：t_vehicle_info
     */
    @TableField("vehicle_id")
    private Integer vehicleId;

    /**
     * 是否缓存，如果当前指的窑炉正在加工，系统自动分配货物到缓存位置，		      并且记录缓存库位，这是当指定窑炉加工完成后系统先判断是否当前缓存有当前等待执行的任务，然后按照先来先执行原则（等待多个任务）自动调用车辆来执行
     */
    @TableField("is_cache")
    private Integer isCache;

    /**
     * 库位id，关联库位表：t_location
     */
    @TableField("location_id")
    private Integer locationId;

    /**
     * 库位名称
     */
    @TableField("location_name")
    private String locationName;


    public static final String ID = "id";

    public static final String VALID = "valid";

    public static final String CREATE_TIME = "create_time";

    public static final String CREATOR_ID = "creator_id";

    public static final String UPDATER_ID = "updater_id";

    public static final String UPDATE_TIME = "update_time";

    public static final String VERSION = "version";

    public static final String STATUS = "status";

    public static final String INTER_CODE = "inter_code";

    public static final String TASK_CODE = "task_code";

    public static final String PALLET_CODE = "pallet_code";

    public static final String A_BEGIN_TIME = "a_begin_time";

    public static final String A_END_TIME = "a_end_time";

    public static final String START_POSITION = "start_position";

    public static final String TARGET_POSITION = "target_position";

    public static final String KILN_ID = "kiln_id";

    public static final String VEHICLE_ID = "vehicle_id";

    public static final String IS_CACHE = "is_cache";

    public static final String LOCATION_ID = "location_id";

    public static final String LOCATION_NAME = "location_name";

    @Override
    protected Serializable pkVal() {
        return this.id;
    }

}
